@@ -249,6 +249,14 @@ atk_text_interface_init (AtkTextIface *iface)
 static void
 html_a11y_text_finalize (GObject *obj)
 {
+        HTMLA11YText *ato = HTML_A11Y_TEXT (obj);
+
+        if (ato->util != NULL) {
+                g_object_unref (ato->util);
+                ato->util = NULL;
+        }
+
+        G_OBJECT_CLASS (parent_class)->finalize (obj);
 }
 
 static void
@@ -430,10 +438,14 @@ html_a11y_text_get_text (AtkText *text, gint start_offset, gint end_offset)
 	if (end_offset == -1)
 		end_offset = to->text_len;
 
-	g_return_val_if_fail (start_offset <= end_offset, NULL);
-	g_return_val_if_fail (start_offset >= 0, NULL);
-	g_return_val_if_fail (start_offset <= to->text_len, NULL);
-	g_return_val_if_fail (end_offset <= to->text_len, NULL);
+	if (start_offset > end_offset)
+		return NULL;
+	if (start_offset < 0)
+		return NULL;
+	if (start_offset > to->text_len)
+		return NULL;
+	if (end_offset > to->text_len)
+		return NULL;
 
 	str = html_text_get_text (to, start_offset);
 
@@ -934,7 +946,7 @@ html_a11y_text_get_offset_at_point (AtkText *text, gint x, gint y,
 	x -= html_x;
 	y -= html_y;
 
-	return_obj = html_engine_get_object_at (top_e, x, y, &offset, FALSE);
+	return_obj = html_engine_get_object_at (top_e, x, y, (guint *) &offset, FALSE);
 		
 	if (obj == return_obj)
 		return offset;
@@ -1154,7 +1166,7 @@ static gint
 html_a11y_text_get_n_links (AtkHypertext *hypertext)
 {
 	HTMLText *text = HTML_TEXT (HTML_A11Y_HTML (hypertext));
-	if (!text || !HTML_IS_TEXT (text))
+	if (!text || ! HTML_IS_TEXT (text))
 		return 0;
 	return g_slist_length (text->links);
 }
